@@ -1,13 +1,25 @@
+import sentry_sdk
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
+from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
+from sentry_sdk.integrations.redis import RedisIntegration
 
+from fief import __version__
 from fief.apps import admin_app, auth_app
 from fief.db import account_engine_manager
 from fief.services.account_creation import create_global_fief_account
 from fief.settings import settings
 
+sentry_sdk.init(
+    dsn=settings.sentry_dsn,
+    environment=settings.environment.value,
+    release=__version__,
+    integrations=[RedisIntegration()],
+)
+
 app = FastAPI(openapi_url=None)
 
+app.add_middleware(SentryAsgiMiddleware)
 app.add_middleware(
     CORSMiddleware,
     allow_origin_regex=settings.allow_origin_regex,
