@@ -4,6 +4,7 @@ from fastapi.staticfiles import StaticFiles
 
 from fief.apps.auth.routers.auth import router as auth_router
 from fief.apps.auth.routers.register import router as register_router
+from fief.apps.auth.routers.reset import router as reset_router
 from fief.apps.auth.routers.token import router as token_router
 from fief.apps.auth.routers.user import router as user_router
 from fief.apps.auth.routers.well_known import router as well_known_router
@@ -16,6 +17,7 @@ from fief.errors import (
     FormValidationError,
     LoginException,
     RegisterException,
+    ResetPasswordException,
     TokenRequestException,
 )
 from fief.paths import STATIC_DIRECTORY
@@ -25,6 +27,7 @@ from fief.services.authentication_flow import AuthenticationFlow
 def include_routers(router: APIRouter) -> APIRouter:
     router.include_router(auth_router)
     router.include_router(register_router)
+    router.include_router(reset_router)
     router.include_router(token_router)
     router.include_router(user_router)
     router.include_router(well_known_router, prefix="/.well-known")
@@ -146,4 +149,23 @@ async def token_request_exception_handler(request: Request, exc: TokenRequestExc
     )
 
 
+@app.exception_handler(ResetPasswordException)
+async def reset_password_exception_handler(
+    request: Request, exc: ResetPasswordException
+):
+    return templates.LocaleTemplateResponse(
+        "reset_password.html",
+        {
+            "request": request,
+            "error": exc.error.error_description,
+            "form_data": exc.form_data,
+            "tenant": exc.tenant,
+            "fatal_error": exc.fatal,
+        },
+        translations=request.scope["translations"],
+        status_code=status.HTTP_400_BAD_REQUEST,
+        headers={"X-Fief-Error": exc.error.error},
+    )
+
+
 __all__ = ["app"]
