@@ -1,7 +1,9 @@
+import os
 from enum import Enum
 from typing import Any, Dict, Optional
+from urllib.parse import urlparse
 
-from pydantic import BaseSettings, Field, validator
+from pydantic import BaseSettings, Field, root_validator, validator
 from sqlalchemy import engine
 
 from fief.crypto.encryption import is_valid_key
@@ -23,6 +25,7 @@ class Settings(BaseSettings):
     environment: Environment
     log_level: str = "DEBUG"
     unit_tests: bool = False
+    sentry_dsn: Optional[str] = None
     root_domain: str
     allow_origin_regex: str
 
@@ -30,13 +33,14 @@ class Settings(BaseSettings):
     encryption_key: bytes
 
     database_type: DatabaseType = DatabaseType.SQLITE
+    database_url: Optional[str] = None
     database_host: Optional[str] = None
     database_port: Optional[int] = None
     database_username: Optional[str] = None
     database_password: Optional[str] = None
     database_name: Optional[str] = "fief.db"
 
-    redis_broker: str = "redis://localhost:6379"
+    redis_url: str = "redis://localhost:6379"
 
     email_provider: AvailableEmailProvider = AvailableEmailProvider.NULL
     email_provider_params: Dict[str, Any] = Field(default_factory=dict)
@@ -67,6 +71,18 @@ class Settings(BaseSettings):
     class Config:
         env_file = ".env"
 
+    @root_validator(pre=True)
+    def parse_database_url(cls, values):
+        database_url = values.get("database_url")
+        if database_url is not None:
+            parsed_database_url = urlparse(database_url)
+            values["database_host"] = parsed_database_url.hostname
+            values["database_port"] = parsed_database_url.port
+            values["database_username"] = parsed_database_url.username
+            values["database_password"] = parsed_database_url.password
+            values["database_name"] = parsed_database_url.path[1:]
+        return values
+
     @validator("encryption_key", pre=True)
     def validate_encryption_key(cls, value: Optional[str]) -> Optional[bytes]:
         if value is None:
